# Revision History

## 1.0.1 (2017/03/21)

- Fixed handling of relative paths in assets.

## 1.0 (2017/01/09)

- Initial stable release.

## 0.2 (2016/06/09)

- Added a `--launch` option to open the page's index.

## 0.1 (2016/06/09)

- Initial release.
